Struct core::marker::ManagedUnstable
[-] [+]
[src]
pub struct Managed;
A type which is considered managed by the GC. This is typically embedded in other types.
pub struct Managed;
A type which is considered managed by the GC. This is typically embedded in other types.
impl !Send for Managedimpl !Sync for Managedimpl Ord for Managedimpl PartialOrd for Managedfn partial_cmp(&self, __arg_0: &Managed) -> Option<Ordering>fn lt(&self, __arg_0: &Managed) -> boolfn le(&self, __arg_0: &Managed) -> boolfn gt(&self, __arg_0: &Managed) -> boolfn ge(&self, __arg_0: &Managed) -> boolimpl Eq for Managedimpl PartialEq for Managedimpl Clone for Managedfn clone(&self) -> Managedfn clone_from(&mut self, source: &Self)
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).